==> guildai-0.8.2.dev1-py2.py3-none-any.whl: guild/tests/uat/remote-check.md <==
# SSH Check

    >>> run("guild check -r guild-uat --offline")
    remote:                    guild-uat ...
    guild_version:             0.8.2...
    guild_install_location:    ...
    guild_home:                ...
    guild_resource_cache:      ...
    installed_plugins:         config_flags, cpu, dask, disk, dvc, exec_script, gpu,
                               ipynb, keras, memory, perf, python_script, quarto_document,
                               queue, r_script, skopt
    python_version:            ...
    python_exe:                ...
    platform:                  ...
    tensorboard_version:       ...
    cuda_version:              ...
    nvidia_smi_version:        ...
    latest_guild_version:      unchecked (offline)
    <exit 0>

Use an inline remote spec.

    >>> from guild import config
    >>> uat_remote = config.user_config()["remotes"]["guild-uat"]
    >>> env_path = uat_remote.get("guild-env") or uat_remote.get("venv-path")
    >>> uat_remote_spec = (
    ...     "%s:%s" % (uat_remote["host"], env_path) if env_path else
    ...     uat_remote["host"]
    ... )

    >>> run("guild check -r ssh:%s --offline" % uat_remote_spec)
    remote:                    ...
    guild_version:             0.8.2...
    guild_install_location:    ...
    guild_home:                ...
    guild_resource_cache:      ...
    installed_plugins:         ...
    python_version:            ...
    python_exe:                ...
    platform:                  ...
    tensorboard_version:       ...
    cuda_version:              ...
    nvidia_smi_version:        ...
    latest_guild_version:      unchecked (offline)
    <exit 0>

==> guildai-0.9.0rc1-py2.py3-none-any.whl: guild/tests/uat/remote-check.md <==
# SSH Check

    >>> run("guild check -r guild-uat --offline")
    remote:                    guild-uat ...
    guild_version:             0.9...
    guild_install_location:    ...
    guild_home:                ...
    guild_resource_cache:      ...
    installed_plugins:         config_flags, cpu, dask, disk, dvc, exec_script, gpu,
                               ipynb, keras, memory, perf, python_script, quarto_document,
                               queue, r_script, resource_flags, skopt
    python_version:            ...
    python_exe:                ...
    platform:                  ...
    tensorboard_version:       ...
    cuda_version:              ...
    nvidia_smi_version:        ...
    latest_guild_version:      unchecked (offline)
    <exit 0>

Use an inline remote spec.

    >>> from guild import config
    >>> uat_remote = config.user_config()["remotes"]["guild-uat"]
    >>> env_path = uat_remote.get("guild-env") or uat_remote.get("venv-path")
    >>> uat_remote_spec = (
    ...     "%s:%s" % (uat_remote["host"], env_path) if env_path else
    ...     uat_remote["host"]
    ... )

    >>> run("guild check -r ssh:%s --offline" % uat_remote_spec)
    remote:                    ...
    guild_version:             0.9...
    guild_install_location:    ...
    guild_home:                ...
    guild_resource_cache:      ...
    installed_plugins:         ...
    python_version:            ...
    python_exe:                ...
    platform:                  ...
    tensorboard_version:       ...
    cuda_version:              ...
    nvidia_smi_version:        ...
    latest_guild_version:      unchecked (offline)
    <exit 0>
